k16.mallard.executor


?ExecutePropsclj

source

?Operationclj

source

?Operationsclj

source

execute!clj

(execute! {:keys [context store operations direction limit] :as props})

Execute the given operations and append to the oplog.

This will handle locking and will mutate the datastore with the changing oplog as operations are applied.

Returns the full oplog on completion.

Execute the given operations and append to the oplog.

This will handle locking and will mutate the datastore with the changing
oplog as operations are applied.

Returns the full oplog on completion.
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries