(load! namespaces)(load! opts namespaces)Dynamically require all given namespaces as operation files.
Functionally this operates nearly identically to [k16.mallard.loader.fs/load!] - for more information on how this works, please read its docstring.
Dynamically require all given namespaces as operation files. Functionally this operates nearly identically to [k16.mallard.loader.fs/load!] - for more information on how this works, please read its docstring.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |