(execute! {:keys [context store operations direction limit] :as props})Execute the given operations and append to the oplog.
This will handle locking and will mutate the datastore with the changing oplog as operations are applied.
Returns the full oplog on completion.
Execute the given operations and append to the oplog. This will handle locking and will mutate the datastore with the changing oplog as operations are applied. Returns the full oplog on completion.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |